dls-bxflow
=======================================================================

Distributed beamline automated data processing workflow engine and gui platform core.

Support beamline-specific science algorithms as workflow tasks.

.. toctree::
    :titlesonly:

    tutorials/index
    how-to/index
    explanations/index
    reference/index
